@@ -1,3 +1,3 @@
 # flake8: noqa
-from . import templates
+from . import templates, ocr
 from .utils import base64_to_image, image_to_base64
